==> rivendell-2.2.0.zip: rivendell-2.2.0/rdcastmanager/rdcastmanager_pt_BR.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Editando Podcast</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation>Link de Mídia:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>E-mail do autor:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Link URL:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Texto Fonte:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>Fonte URL:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Comentários da URL:</translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation>Ar Data/Hora:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Postado em:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Cast Expira:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="obsolete">Expira em:</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Espere</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Publicação:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>&amp;Relatório do
Episódio</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation>Lista de POdcast</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Áudio Uploading...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation>Mostrar Casts não expirados</translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation>Mostrar Casts Ativos</translation>
    </message>
    <message>
        <source> </source>
        <translation>
</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Origem</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expira</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Postar  
&amp;Cartão</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Postar 
&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>&amp;Relatório de
Assinaturas</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation>Erro na Postagem</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation>Deletar PodCast</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation>Tem certeza que você quer deletar este podcast?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation>Deletando Podcast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Erro Interno</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="obsolete">Não foi Possível gerar comando para eliminar!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Erro Remoto</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="obsolete">Não foi possível deletar áudio remoto!
Continuar deletando cast?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation>RDPodcast - Cliente</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Usuário: [Desconhecido] </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi possível conectar</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Nome chave</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Nome do Feed</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Casts</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Ver 
Feed</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished">&amp;Selecionar</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-2.15.1.zip: rivendell-2.15.1/rdcastmanager/rdcastmanager_pt_BR.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Editando Podcast</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation>Link de Mídia:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>E-mail do autor:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Link URL:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Texto Fonte:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>Fonte URL:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Comentários da URL:</translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation>Ar Data/Hora:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Postado em:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Cast Expira:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="obsolete">Expira em:</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Espere</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Publicação:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>&amp;Relatório do
Episódio</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation>Lista de POdcast</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Áudio Uploading...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation>Mostrar Casts não expirados</translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation>Mostrar Casts Ativos</translation>
    </message>
    <message>
        <source> </source>
        <translation>
</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Origem</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expira</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Postar  
&amp;Cartão</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Postar 
&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>&amp;Relatório de
Assinaturas</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation>Erro na Postagem</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation>Deletar PodCast</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation>Tem certeza que você quer deletar este podcast?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation>Deletando Podcast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Erro Interno</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="obsolete">Não foi Possível gerar comando para eliminar!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Erro Remoto</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="obsolete">Não foi possível deletar áudio remoto!
Continuar deletando cast?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="obsolete">RDPodcast - Cliente</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Usuário: [Desconhecido] </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi possível conectar</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Nome chave</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Nome do Feed</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Casts</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Ver 
Feed</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished">&amp;Selecionar</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
